# How to contribute?

[![Open in Visual Studio Code](https://img.shields.io/badge/vscode-open-blue?logo=visualstudiocode)](https://open.vscode.dev/ComPWA/ampform)
[![GitPod](https://img.shields.io/badge/gitpod-open-blue?logo=gitpod)](https://gitpod.io/#https://github.com/ComPWA/ampform)

This package is part of the [ComPWA Organization](https://github.com/ComPWA).
For more information about how to contribute to the packages, go to
[compwa-org.rtfd.io/en/stable/develop.html](https://compwa-org.rtfd.io/en/stable/develop.html)!
